@@ -4,7 +4,7 @@ package Dist::Zilla::App::Command::stale;
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.046';
+our $VERSION = '0.047';
 
 use Dist::Zilla::App -command;
 
@@ -112,12 +112,13 @@ sub execute
             require Term::ANSIColor;
             Term::ANSIColor->VERSION('3.00');
             print STDERR Term::ANSIColor::colored("Some authordeps were missing. Run the stale command again to check for regular dependencies.\n", 'bright_yellow');
+            exit 1;
         }
 
         undef;  # ensure $zilla = undef
     };
 
-    return if not $zilla;
+    exit 2 if not $zilla;
 
     my $error;
     my @stale_modules = Try::Tiny::try {
@@ -167,7 +168,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -186,6 +187,14 @@ When a L<[PromptIfStale]|Dist::Zilla::Plugin::PromptIfStale> configuration is
 present in F<dist.ini>, its configuration is honoured (unless C<--all> is
 used); if there is no such configuration, behaviour is as for C<--all>.
 
+=for stopwords thusly
+
+If not everything can be installed in one pass (typically, if a plugin used by
+F<dist.ini> is missing), a message will be printed to C<STDERR> and the exit
+code will be 1.  This allows you to chain commands thusly:
+
+    dzil stale --all | cpanm && dzil build && dzil test --release
+
 =head1 OPTIONS
 
 =head2 --all
@@ -199,14 +208,6 @@ quite regularly! You should do this too.
 
 =for Pod::Coverage stale_modules
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PromptIfStale>
-(or L<bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-PromptIfStal@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -217,6 +218,19 @@ L<Dist::Zilla::Plugin::PromptIfStale>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PromptIfStale>
+(or L<bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+http://dzil.org/#mailing-list.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
