@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.045-14-gc74192e
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.046-7-g4665148
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.046';
+our $VERSION = '0.047';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -390,6 +390,7 @@ sub _indexed_version_via_query
     my ($self, $module) = @_;
 
     die 'should not be here - get 02packages instead' if $self->index_base_url;
+    die 'no module?' if not $module;
 
     my $url = 'http://cpanmetadb.plackperl.org/v1.0/package/' . $module;
     $self->log_debug([ 'fetching %s', $url ]);
@@ -439,6 +440,7 @@ sub _indexed_version_via_02packages
 {
     my ($self, $module) = @_;
 
+    die 'no module?' if not $module;
     my $packages = $self->_get_packages;
     return undef if not $packages;
     my $package = $packages->package($module);
@@ -460,7 +462,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -560,14 +562,6 @@ a list reference of error messages describing the issues found
 
 =back
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PromptIfStale>
-(or L<bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -586,6 +580,19 @@ L<Dist::Zilla::Plugin::Prereqs::MatchInstalled>, L<Dist::Zilla::Plugin::Prereqs:
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PromptIfStale>
+(or L<bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-PromptIfStale@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+http://dzil.org/#mailing-list.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
